"use strict";
Object.defineProperty(exports, "__esModule", {
  value: true
});
function _export(target, all) {
  for (var name in all)
    Object.defineProperty(target, name, {
      enumerable: true,
      get: all[name]
    });
}
_export(exports, {
  getErrorCause: function() {
    return getErrorCause;
  },
  ParsedError: function() {
    return ParsedError;
  }
});
const _interop_require_default = require("@swc/helpers/_/_interop_require_default");
const _assert = /* @__PURE__ */ _interop_require_default._(require("assert"));
const _util = require("util");
const _lodash = /* @__PURE__ */ _interop_require_default._(require("@modern-js/utils/lodash"));
const _stacktracey = /* @__PURE__ */ _interop_require_default._(require("../../compiled/stacktracey"));
const _utils = require("../shared/utils");
const _context = require("./context");
const getErrorCause = (error) => {
  (0, _assert.default)(typeof error === "object", "Error must be an object");
  const err = error;
  return [
    err.cause,
    err.error,
    err.originalError
  ].find(_lodash.default.isError);
};
class ParsedError {
  [_util.inspect.custom]() {
    const formatted = (0, _utils.formatError)(this.context.formatters, this);
    return formatted;
  }
  freeze() {
    const ret = {
      ...this,
      [_util.inspect.custom]: _lodash.default.constant((0, _util.inspect)(this))
    };
    return Object.freeze(ret);
  }
  constructor(error, context = new _context.Context()) {
    this.type = "error";
    this.causes = [];
    this.trace = [];
    this.raw = error;
    var _this_raw_name;
    this.name = (_this_raw_name = this.raw.name) !== null && _this_raw_name !== void 0 ? _this_raw_name : "Error";
    var _this_raw_message;
    this.message = (_this_raw_message = this.raw.message) !== null && _this_raw_message !== void 0 ? _this_raw_message : "";
    this.context = context;
    if (context.withSources) {
      this.trace = new _stacktracey.default(error).withSources().items;
    } else {
      this.trace = new _stacktracey.default(error).items;
    }
    const rawCause = getErrorCause(this.raw);
    if (rawCause) {
      this.cause = new ParsedError(rawCause);
      this.cause.parent = this;
      this.causes.push(this.cause, ...this.cause.causes);
    }
  }
}
